@@ -1,5 +1,5 @@
-from av.subtitles.subtitle import AssSubtitle, BitmapSubtitle
 import av
+from av.subtitles.subtitle import AssSubtitle, BitmapSubtitle
 
 from .common import TestCase, fate_suite
 
@@ -23,7 +23,8 @@ class TestSubtitle(TestCase):
 
         sub = subset[0]
         self.assertIsInstance(sub, AssSubtitle)
-        self.assertEqual(sub.ass, "0,0,Default,,0,0,0,,- Test 1.\\N- Test 2.")
+        self.assertEqual(sub.type, b"ass")
+        self.assertEqual(sub.ass, b"0,0,Default,,0,0,0,,- Test 1.\\N- Test 2.")
 
     def test_vobsub(self):
         path = fate_suite("sub/vobsub.sub")
@@ -43,10 +44,12 @@ class TestSubtitle(TestCase):
 
         sub = subset[0]
         self.assertIsInstance(sub, BitmapSubtitle)
+        self.assertEqual(sub.type, b"bitmap")
         self.assertEqual(sub.x, 259)
         self.assertEqual(sub.y, 379)
         self.assertEqual(sub.width, 200)
         self.assertEqual(sub.height, 24)
+        self.assertEqual(sub.nb_colors, 4)
 
         bms = sub.planes
         self.assertEqual(len(bms), 1)
